python-timezones
----------------

![](https://github.com/Doist/python-timezones/workflows/Tests/badge.svg)

A Python library that provides better selection of common timezones,
can output HTML and auto select the best timezone based on user's IP.

Visit https://doist.github.io/python-timezones/ for more information.

Copyright: 2012-2022 by Doist
License: MIT.
